Covariates on each of 71 lawyers in a northeastern American law firm. Note the first column is a column of 1's.
lawyers.covariatesA data frame with 71 observations on the following 8 variables.
Intercepta column of 1s should always be the first column.
Senioritya factor with levels 1 = partner, 2 = associate.
Gendera factor with 1 = male, 2 = female.
Officea factor with levels 1 = Boston, 2 = Hartford and 3 = Providence
Yearsa numeric vector detailing years with the firm.
Agea numeric vector detailing the age of each lawyer.
Practicea factor with levels 1 = litigation and 2 = corporate.
Schoola factor with levels 1 = Harvard or Yale, 2 = University of Connecticut and 3 = Other.